module Outreach
  module Errors
    UNAUTHORIZED_ID = 'unauthenticatedRequest'.freeze
    class Unauthorized < StandardError; end

    def check_for_error(_status_code, response_body)
      response_hash = JSON.parse(response_body)
      errors = []
      if !response_hash['errors'].nil? && response_hash['errors'].any?
        errors = response_hash['errors'].map { |error| create_error_hash(error) }
      end

      errors.map do |error|
        case error[:id]
        when UNAUTHORIZED_ID
          raise Unauthorized, error[:detail]
        else
          raise StandardError, error[:title] + ': ' + error[:detail]
        end
      end
    end

    private

    def create_error_hash(error)
      {
        id: error['id'],
        title: error['title'],
        detail: error['detail']
      }
    end
  end
end
